# jieba_zh

## submodule

ADD:
1. `git submodule add https://github.com/Chunshan-Theta/jieba_zh.git`
2. `git submodule init`
3. `git submodule update`



UPDATE:
1. `git pull`
2. `git submodule update`


UPDATE FROM LATEST:
1. `git submodule foreach "(git checkout main; git pull)"  `
